package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

import static com.winhc.bigdata.udf.GetCompanyChangeInfo.md5;

/**
 * @Author: π
 * @Date: 2023/7/27 16:26
 * 招投标转换
 */
public class CompanyTmTrans extends UDF {

    private static final Pattern pattern1 = Pattern.compile("(\\d{4})年(\\d{1,2})月(\\d{1,2})日.*");

    public String evaluate(String date) {
        if (StringUtils.isBlank(date)) return null;
        return extracted(date);

    }

    private static String extracted(String date) {
        String tmpDate = null;
        try {
            if (date.contains("年")) {
                Matcher m0 = pattern1.matcher(date);
                boolean matches = m0.matches();
                if (matches) {
                    String year = m0.group(1);
                    String month = m0.group(2);
                    String day = m0.group(3);
                    if (month.length() < 2) {
                        month = "0" + month;
                    }
                    if (day.length() < 2) {
                        day = "0" + day;
                    }
                    tmpDate = year + "-" + month + "-" + day;
                }
            } else if (date.contains("/")) {
                tmpDate = date.split(" ")[0].replaceAll("/", "-");
            } else if (date.contains("-")) {
                tmpDate = date.split(" ")[0];
            }
            DateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
            formatter.parse(tmpDate);
            return tmpDate;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    public String evaluate(String applicant_1, String applicant_keyno_1, String applicant_2, String applicant_keyno_2) {
        JSONArray jj = new JSONArray();
        if (StringUtils.isNotBlank(applicant_1)) {
            jj.add(new JSONObject()
                    .fluentPut("applicant_name", applicant_1)
                    .fluentPut("applicant_keyno", applicant_keyno_1)
            );
        }

        if (StringUtils.isNotBlank(applicant_2)) {
            jj.add(new JSONObject()
                    .fluentPut("applicant_name", applicant_2)
                    .fluentPut("applicant_keyno", applicant_keyno_2)
            );
        }

        return JSON.toJSONString(jj);
    }
    public String evaluate(String reg_no, String int_cls) {
        String image_name = reg_no + "/" + int_cls + ".jpg";
        String filename_md5 = md5(image_name).substring(8, 24);
        List<String> list = new ArrayList<>();
        for (int i = 0; i < filename_md5.length(); i += 2) {
            list.add(filename_md5.substring(i, i + 2));
        }
        list.add(image_name);
        String re = String.join("/", list);
        return "https://winhc-trademark.oss-cn-shanghai.aliyuncs.com/" + re;
    }


    public static void main(String[] args) {

        CompanyTmTrans j = new CompanyTmTrans();
        System.out.println(j.evaluate("2005-09-28 00:00:00"));
        System.out.println(j.evaluate("2005年9月8日 00:00:00"));
        System.out.println(j.evaluate("2005年09月18日"));
        System.out.println(j.evaluate("2005/09/28 00:00:00"));
        System.out.println(j.evaluate("2005-09-28"));
        System.out.println(j.evaluate("35186311", "41"));
        System.out.println(j.evaluate("a1", null, "a2", null));
        System.out.println(j.evaluate("a1", "11", "a2", null));
        System.out.println(j.evaluate("", null, "a2", "11"));
        System.out.println(j.evaluate(null, null, null, "11"));

    }
}
