package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;



/**
 * @Author: π
 * @Description: 法院转换省份
 */
public class CourtName2Province extends UDF {

    private static Map<String, String> map = new HashMap<>();

    static {
        InputStream in = CourtName2Province.class.getClassLoader().getResourceAsStream("all_court.txt");
        BufferedReader br = new BufferedReader(new InputStreamReader(in));
        String line = null;
        while (true) {
            try {
                if ((line = br.readLine()) == null) break;
            } catch (IOException e) {
                e.printStackTrace();
            }
            String[] arr = line.split(",", -1);
            String court = arr[0];
            String code = arr[1];
            if (StringUtils.isNotBlank(court) && StringUtils.isNotBlank(court)) {
                map.put(court, code);
            }
        }
    }

    public String evaluate(String courtName) {
        if (StringUtils.isBlank(courtName)) {
            return null;
        }
        List<String> re = Arrays.stream(courtName.split(","))
                .filter(StringUtils::isNotBlank)
                .distinct()
                .map(x -> map.getOrDefault(x, ""))
                .filter(StringUtils::isNotBlank)
                .distinct().collect(Collectors.toList());
        return JSON.toJSONString(re);

    }

    public static void main(String[] args) {
        CourtName2Province res = new CourtName2Province();
        System.out.println(res.evaluate("北京市丰台区人民法院,北京市高级人民法院,北京市第二中级人民法院,江苏省无锡市中级人民法院,无锡市惠山区人民法院,江苏省无锡市惠山区人民法院"));
    }
}
