package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.Optional;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 字符串去符号
 * [{"amomon":"20万元人民币","paymet":"其它","time":""}]
 */
public class GetCapitalActualAmt extends UDF {

    private static final Pattern pattern_number = Pattern.compile("[^0-9.]");

    public Double evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;

        Optional<BigDecimal> reduce = JSON.parseArray(info).toJavaList(JSONObject.class).stream()
                .map(j -> cleanupNotNumber(j.getString("amomon")))
                .filter(Objects::nonNull)
                .collect(Collectors.toList())
                .stream()
                .reduce(BigDecimal::add);
        return reduce.isPresent() ? reduce.get().doubleValue() : null;
    }

    public static BigDecimal cleanupNotNumber(String s) {
        if (StringUtils.isBlank(s)) return null;
        String s1 = pattern_number.matcher(s).replaceAll("");
        try {
            return new BigDecimal(s1).stripTrailingZeros();
        } catch (Exception e) {
            return null;
        }
    }


    public static void main(String[] args) {
        String info = "[{\"amomon\":\"100.250100万元\",\"paymet\":\"货币\",\"time\":\"2011-12-14\"},{\"amomon\":\"60.0000万元\",\"paymet\":\"货币\",\"time\":\"2012-02-08\"}]";
        info = "[{\"amomon\":\"1.481万人民币\",\"paymet\":\"货币\",\"time\":\"2011-01-26\"},{\"amomon\":\"6.7万人民币\",\"paymet\":\"实物\",\"time\":\"2011-01-26\"}]";
        GetCapitalActualAmt j = new GetCapitalActualAmt();
        System.out.println(j.evaluate(info));
    }
}
