package com.winhc.bigdata.udf;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.util.Comparator;
import java.util.Optional;

public class GetCaseAmt extends UDF {

    public Double evaluate(String case_info) {

        double case_amt = JSON.parseArray(Optional.ofNullable(case_info)
                .orElse("[]"))
                .toJavaList(JSONObject.class)
                .stream()
                .sorted(Comparator.comparing(x -> {
                    JSONObject j = (JSONObject) x;
                    return stageWeight(j.getString("case_stage"));
                }).reversed())
                .mapToDouble(y -> y.getDouble("amt"))
                .findFirst().orElse(0);

        return case_amt > 0 ? case_amt : null;
    }

    public Integer stageWeight(String stage_name) {
        if (StringUtils.isBlank(stage_name)) return 0;
        if (StrUtil.containsAny(stage_name, "执")) {
            return 5;
        }
        if (StrUtil.containsAny(stage_name, "再")) {
            return 4;
        }
        if (StrUtil.containsAny(stage_name, "二")) {
            return 3;
        }
        if (StrUtil.containsAny(stage_name, "一")) {
            return 2;
        }
        return 1;
    }

    public static void main(String[] args) {
        GetCaseAmt c = new GetCaseAmt();
        System.out.println(c.evaluate("[{\"case_stage\":\"民事一审\",\"amt\":7.645169},{\"case_stage\":\"民事二审\",\"amt\":7.645169}]"));
    }

}