package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Locale;
import java.util.Objects;
import java.util.regex.Pattern;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 变更数据处理
 */
public class GetCompanyChangeInfo extends UDF {

    private static final Pattern first_p = Pattern.compile("[^\\u4e00-\\u9fa50-9a-zA-Z()（）]");
    private static final Pattern second_p = Pattern.compile("[(（][^(（]+[)）]$");
    private static final Pattern third_p = Pattern.compile("[^\\u4e00-\\u9fa50-9a-zA-Z]");
    private static final Pattern html_p = Pattern.compile("<[^>]+>");

    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        JSONObject j1 = JSONObject.parseObject(info);

        return j1.getJSONArray("change_info").stream().map(item -> {
            JSONObject tj = new JSONObject();
            tj.putAll(((JSONObject) item));
            JSONObject j2 = new JSONObject()
                    .fluentPut("company_id", tj.getString("company_id"))
                    .fluentPut("company_name", tj.getString("company_name"))
                    .fluentPut("change_item", tj.getString("change_item"))
                    .fluentPut("content_before", tj.getString("content_before"))
                    .fluentPut("content_after", tj.getString("content_after"))
                    .fluentPut("change_time", tj.getString("change_time"))
                    .fluentPut("create_time", tj.getString("create_time"))
                    .fluentPut("update_time", tj.getString("update_time"))
                    .fluentPut("deleted", tj.getInteger("deleted"));

            String rowkey = getChangeRowkey(tj.getString("company_id"), j2);
            j2.fluentPut("rowkey", rowkey);
            return j2.toJSONString();
        }).collect(Collectors.toList());
    }

    public String replace(Object value) {
        return value == null ? null : value.toString().replaceAll("\\s", "");
    }

    private static String getChangeRowkey(String companyId, JSONObject j) {
        String content_before = cleanupChange(j.getString("content_before"));
        String content_after = cleanupChange(j.getString("content_after"));
        String change_time = splitDate(j.getString("change_time"));
        if (StringUtils.isEmpty(content_before) && StringUtils.isEmpty(content_after)) {
            return null;
        }
        return concatws("_", companyId, md5(concatws("", change_time, content_before, content_after)));
    }

    public static String cleanupChange(String val) {
        if (com.aliyun.odps.utils.StringUtils.isEmpty(val)) return "";
        val = html_p.matcher(val).replaceAll("");
        val = first_p.matcher(val).replaceAll("");
        val = second_p.matcher(val).replaceAll("");
        return third_p.matcher(val).replaceAll("");
    }

    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }

    public static String splitDate(String date) {
        try {
            if (StringUtils.isEmpty(date)) {
                return null;
            } else {
                return date.split(" ")[0];
            }
        } catch (Exception e) {
            return null;
        }
    }

    public static void main(String[] args) {
        String info = "{\"change_info\":[{\"change_item\":\"经营范围\",\"change_time\":\"2019-03-08 00:00:00\",\"company_id\":\"ebc57788b7da89dde34ce85deb94bbff\",\"company_name\":\"北京高雅时尚装饰有限公司\",\"content_after\":\"家居装饰、设计；销售五金交电、化工产品（不含危险化学品）、日用品、门窗。（企业依法自主选择经营项目，开展经营活动；依法须经批准的项目，经相关部门批准后依批准的内容开展经营活动；不得从事本市产业政策禁止和限制类项目的经营活动。）\",\"content_before\":\"家居装饰、设计；销售五金交电、化工产品（不含危险化学品）、日用品。（企业依法自主选择经营项目，开展经营活动；依法须经批准的项目，经相关部门批准后依批准的内容开展经营活动；不得从事本市产业政策禁止和限制类项目的经营活动。）\",\"create_time\":\"2023-07-03 16:44:45\",\"deleted\":0,\"rowkey\":\"\",\"update_time\":\"2023-07-03 16:44:45\"}]}";
        GetCompanyChangeInfo j = new GetCompanyChangeInfo();
        System.out.println(j.evaluate(info));
        System.out.println(cleanup("〔2023〕(南)桂综执市监罚罚字216号"));
    }
}
