package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 专利转换
 */
public class GetCompanyPatentNewInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");

    public static String substr(String str, Integer num) {
        if (StringUtils.isEmpty(str)) {
            return "";
        } else {
            return str.substring(num);
        }
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }

    public String logoPath(String app_number) {
        String filename_md5 = md5(app_number).substring(8, 24);
        List<String> list = new ArrayList<>();
        for (int i = 0; i < filename_md5.length(); i += 2) {
            list.add(filename_md5.substring(i, i + 2));
        }
        list.add(app_number + ".jpg");
        String re = String.join("/", list);
        return "https://winhc-patent.oss-cn-shanghai.aliyuncs.com/" + re;
    }

    public String evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        JSONObject data = JSONObject.parseObject(info);
        JSONObject rej = new JSONObject();

        String make_corrections_date;
        String re_make_corrections_date = null;
        if (data.containsKey("make corrections_date")) {
            make_corrections_date = data.getString("make corrections_date");
        } else {
            make_corrections_date = data.getString("make_corrections_date");
        }
        if (StringUtils.isNotBlank(make_corrections_date)) {
            re_make_corrections_date = make_corrections_date.replaceAll("\\.", "-").replaceAll(" ", "") + " 00:00:00";
        }

        JSONArray legalInfo = data.getJSONArray("legal_info");
        JSONObject date = Optional.ofNullable(legalInfo).orElse(new JSONArray()).toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("date")))
                .max(Comparator.comparing(d -> d.getString("date"))).orElse(new JSONObject());


        String appNumber = data.getString("app_number");
        String pubNumber = data.getString("pub_number");
        if (StringUtils.isBlank(appNumber)) return null;

        String nowTime = nowDate(YYYY_MM_DDHHMMSS);

        String rowkey = md5(cleanup(concatws("", substr(appNumber, 2))));

        rej
                .fluentPut("rowkey", rowkey)
                .fluentPut("pub_number", pubNumber)
                .fluentPut("authorize_num", data.getString("authorize_num"))
                .fluentPut("applicant_name_info", data.getJSONArray("applicant_name_info"))
                .fluentPut("app_number", appNumber)
                .fluentPut("app_date", data.getString("app_date"))
                .fluentPut("make_corrections_date", re_make_corrections_date)
                .fluentPut("pub_date", data.getString("pub_date"))
                .fluentPut("authorize_date", data.getString("authorize_date"))
                .fluentPut("title", data.getString("title"))
                .fluentPut("main_ipc", data.getString("main_ipc"))
                .fluentPut("ipc", data.getJSONArray("ipc"))
                .fluentPut("inventor_name", data.getJSONArray("inventor_name"))
                .fluentPut("priority", data.getJSONArray("priority"))
                .fluentPut("agency_name", data.getString("agency_name"))
                .fluentPut("agent_name", data.getJSONArray("agent_name"))
                .fluentPut("address", data.getString("address"))
                .fluentPut("pat_type", data.getString("pat_type"))
                .fluentPut("abs", data.getString("abs"))
                .fluentPut("last_lprs", date.getString("status"))
                .fluentPut("simple_status_code", null)
                .fluentPut("legal_info", data.getJSONArray("legal_info"))
                .fluentPut("main_pic_url", logoPath(appNumber))
                .fluentPut("update_time", nowTime)
                .fluentPut("create_time", nowTime)
                .fluentPut("pdf_url", null)
                .fluentPut("deleted", 0)
        ;
        return JSONObject.toJSONString(rej);
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"agent_name\":[\"周靖\",\"郑霞\"],\"applicant_name_info\":[{\"name\":\"特鲁塔奇科技公司\"}],\"title\":\"用于无创地确定组织内的酒精的系统\",\"pub_date\":\"2012-02-29 00:00:00\",\"main_ipc\":\"A61B5/00\",\"update_time\":\"2023-08-07 10:11:05\",\"app_date\":\"2010-01-23 00:00:00\",\"rowkey\":\"3264eda3c185c8359166ab8c9e316672\",\"main_pic_url\":\"https://winhc-patent.oss-cn-shanghai.aliyuncs.com/20/ee/f8/22/3b/76/1b/83/CN201080013623.2.jpg\",\"ipc\":[\"A61B5/00\"],\"agency_name\":\"北京安信方达知识产权代理有限公司\",\"address\":\"美国新墨西哥州\",\"create_time\":\"2023-08-07 10:11:05\",\"priority\":[{\"priority_date\":\"2009-01-25\",\"priority_num\":\"US61/147,107\"}],\"pub_number\":\"CN102365047A\",\"abs\":\"公开了用于通过定量红外光谱法在临床上相关的精确度和准确度水平无创地确定人组织的属性的装置和方法。系统包括被优化来对付组织光谱的复杂性、高信噪比和光度测定准确性要求、组织采样误差和校准维持问题。子系统包括照明/调制子系统、组织采样子系统、校准维护子系统、FTIR分光计子系统、数据采样子系统和计算子系统。\",\"deleted\":0,\"pat_type\":\"发明公布\",\"app_number\":\"CN201080013623.2\",\"inventor_name\":[\"特伦特·里德尔\",\"本·沃尔斯蒂格\",\"迈克·米尔斯\",\"本特利·拉克索宁\"],\"legal_info\":[{\"detail\":\"公布\",\"date\":\"2023-08-01\",\"status\":\"公布\"}]}";
        GetCompanyPatentNewInfo j = new GetCompanyPatentNewInfo();
        System.out.println(j.evaluate(info));
    }
}
