package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetCompletionAcceptanceInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }


    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        return Optional.ofNullable(JSONObject.parseObject(info).getJSONArray("records"))
                .orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("prjNum")))
                .map(d -> {
                    JSONObject j = new JSONObject();
                    String nowTime = nowDate(YYYY_MM_DDHHMMSS);
                    String prjnum = d.getString("prjNum");
                    String prjfinishnum = d.getString("prjFinishNum");
                    String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", prjfinishnum))));
                    j.fluentPut("rowkey", rowkey)
                            .fluentPut("provinceprjfinishnum", d.getString("provincePrjFinishNum"))
                            .fluentPut("prjfinishnum", d.getString("prjFinishNum"))
                            .fluentPut("builderlicencenum", d.getString("builderLicenceNum"))
                            .fluentPut("factcost", d.getString("factCost"))
                            .fluentPut("prjnum", d.getString("prjNum"))
                            .fluentPut("factarea", d.getString("factArea"))
                            .fluentPut("length", d.getString("length"))
                            .fluentPut("span", d.getString("span"))
                            .fluentPut("factsize", d.getString("factSize"))
                            .fluentPut("bdate", d.getString("bDate") + " 00:00:00")
                            .fluentPut("structural_system", null)
                            .fluentPut("edate", d.getString("eDate")+ " 00:00:00")
                            .fluentPut("mark", d.getString("mark"))
                            .fluentPut("create_time", nowTime)
                            .fluentPut("update_time", nowTime)
                            .fluentPut("deleted", 0)
                    ;
                    return JSONObject.toJSONString(j);
                })
                .collect(Collectors.toList());
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"records\":[{\"bDate\":\"2017-11-03\",\"cREATEDATE\":1547811476000,\"dataLevel\":\"D\",\"eDate\":\"2018-06-01\",\"factArea\":\"0\",\"factCost\":2278.82,\"factSize\":\"/\",\"prjFinishNum\":\"4290051901220016-JX-001\",\"prjNum\":\"4290051901220016\",\"prjStructureTypeNum\":\"099\",\"provincePrjFinishNum\":\"4290051709280213-JX-004\"}],\"yhc_time\":\"2023-03-20\"}";
        GetCompletionAcceptanceInfo j = new GetCompletionAcceptanceInfo();
        System.out.println(j.evaluate(info));
    }
}
