package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetConstructionBidInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }


    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        return Optional.ofNullable(JSONObject.parseObject(info).getJSONArray("records"))
                .orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("prjNum")))
                .map(d -> {
                    JSONObject j = new JSONObject();
                    String nowTime = nowDate(YYYY_MM_DDHHMMSS);
                    String prjnum = d.getString("prjNum");
                    String tendernum = d.getString("tenderNum");
                    String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", tendernum))));
                    j.fluentPut("rowkey", rowkey)
                            .fluentPut("datalevel", d.getString("dataLevel"))
                            .fluentPut("constructorname", d.getString("constructorName"))
                            .fluentPut("idcard_type", d.getString("iDCardTypeNum"))
                            .fluentPut("idcard", d.getString("constructorIDCard"))
                            .fluentPut("tendercorpname", d.getString("tenderCorpName"))
                            .fluentPut("tendercorpname_credit_code", d.getString("tenderCorpCode"))
                            .fluentPut("invite_tenders_type", d.getString("tenderClassNum"))
                            .fluentPut("invite_tenders_way", d.getString("tenderTypeNum"))
                            .fluentPut("agencycorpname", d.getString("agencyCorpName"))
                            .fluentPut("agencycorpname_credit_code", d.getString("agencyCorpCode"))
                            .fluentPut("prjsze", d.getString("prjSize"))
                            .fluentPut("area", d.getString("area"))
                            .fluentPut("prjnum", prjnum)
                            .fluentPut("tendernum", d.getString("tenderNum"))
                            .fluentPut("createdate", getDateString(d.getLong("createDate")))
                            .fluentPut("tenderresultdate", d.getString("tenderResultDate") + " 00:00:00")
                            .fluentPut("tendermoney", d.getString("tenderMoney"))
                            .fluentPut("provincetendernum", d.getString("provinceTenderNum"))
                            .fluentPut("update_time", nowTime)
                            .fluentPut("create_time", nowTime)
                            .fluentPut("deleted", 0)
                    ;
                    return JSONObject.toJSONString(j);
                })
                .collect(Collectors.toList());
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"records\":[{\"agencyCorpCode\":\"/\",\"agencyCorpName\":\"/\",\"area\":2086.79,\"constructorIDCard\":\"/**********\",\"constructorName\":\"钱策勋\",\"createDate\":1429200000000,\"dataLevel\":\"D\",\"iDCardTypeNum\":\"1\",\"prjNum\":\"5134371405140101\",\"prjSize\":\"2086.7900\",\"provinceTenderNum\":\"/\",\"tenderClassNum\":\"006\",\"tenderCorpCode\":\"91510000064451046D\",\"tenderCorpId\":\"002105291248649695\",\"tenderCorpName\":\"四川浩天建筑工程有限公司\",\"tenderNum\":\"5134371405140101-BZ-001\",\"tenderResultDate\":\"2015-04-17\",\"tenderTypeNum\":\"001\"}],\"yhc_time\":\"2023-03-31\"}";
        GetConstructionBidInfo j = new GetConstructionBidInfo();
        System.out.println(j.evaluate(info));
    }
}
