package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetConstructionContractInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }


    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        return Optional.ofNullable(JSONObject.parseObject(info).getJSONArray("records"))
                .orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("prjNum")))
                .map(d -> {
                    JSONObject j = new JSONObject();
                    String nowTime = nowDate(YYYY_MM_DDHHMMSS);
                    String prjnum = d.getString("prjNum");
                    String recordnum = d.getString("recordNum");
                    String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", recordnum))));
                    j.fluentPut("rowkey", rowkey)
                            .fluentPut("recordnum", d.getString("recordNum"))
                            .fluentPut("contractnum", d.getString("contractNum"))
                            .fluentPut("provincecontractnum", d.getString("provinceContractNum"))
                            .fluentPut("prjnum", d.getString("prjNum"))
                            .fluentPut("contractmoney", d.getString("contractMoney"))
                            .fluentPut("contracttypenum", d.getString("contractTypeNum"))
                            .fluentPut("prjsize", d.getString("prjSize"))
                            .fluentPut("propietorcorpname", d.getString("propietorCorpName"))
                            .fluentPut("propietorcorpname_credit_code", d.getString("propietorCorpCode"))
                            .fluentPut("contractorcorpname", d.getString("contractorCorpName"))
                            .fluentPut("contractorcorpname_credit_code", d.getString("contractorCorpCode"))
                            .fluentPut("joint_contractorcorpname", d.getString("unionCorpName"))
                            .fluentPut("joint_contractorcorpname_credit_code", d.getString("unionCorpCode"))
                            .fluentPut("contractdate", d.getString("contractDate") + " 00:00:00")
                            .fluentPut("createdate", getDateString(d.getLong("createDate")))
                            .fluentPut("datalevel", d.getString("dataLevel"))
                            .fluentPut("create_time", nowTime)
                            .fluentPut("update_time", nowTime)
                            .fluentPut("deleted", 0)
                    ;
                    return JSONObject.toJSONString(j);
                })
                .collect(Collectors.toList());
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"records\":[{\"contractDate\":\"2011-06-10\",\"contractMoney\":159.65,\"contractNum\":\"1102JS0101CZ01000\",\"contractTypeNum\":\"301\",\"contractorCorpId\":\"002105291258796242\",\"contractorCorpName\":\"上海海塘水利市政工程有限公司\",\"createDate\":1309968000000,\"dataLevel\":\"D\",\"prjNum\":\"3101161105099903\",\"propietorCorpName\":\"上海市金山区海塘管理所\",\"provinceContractNum\":\"W2011060135335\",\"recordNum\":\"3101161105099903-HZ-001\"}],\"yhc_time\":\"2023-04-13\"}";
        GetConstructionContractInfo j = new GetConstructionContractInfo();
        System.out.println(j.evaluate(info));
    }
}
