package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.Objects;
import java.util.regex.Pattern;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.udf.GetConstructionContractInfo.md5;
import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetConstructionPermitInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }

    private static final Pattern pattern_number = Pattern.compile("[^0-9.]");

    public static String cleanupNotNumber(String s) {
        if (StringUtils.isBlank(s)) return "";
        String s1 = pattern_number.matcher(s).replaceAll("");
        try {
            return new BigDecimal(s1).stripTrailingZeros().toPlainString();
        } catch (Exception e) {
            return "";
        }
    }

    public String evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        JSONObject d0 = JSONObject.parseObject(info);
        JSONObject d = d0.getJSONObject("xuke");
        JSONObject j = new JSONObject();
        String nowTime = nowDate(YYYY_MM_DDHHMMSS);
        String prjnum = d.getString("PRJNUM");
        if (StringUtils.isBlank(prjnum)) return null;
        String builderlicencenum = d.getString("BUILDERLICENCENUM");

        String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", builderlicencenum))));

        j.fluentPut("rowkey", rowkey)
                .fluentPut("conprjname", d.getString("CONPRJNAME"))
                .fluentPut("builderlicencenum", builderlicencenum)
                .fluentPut("provincebuilderlicencenum", d.getString("PROVINCEBUILDERLICENCENUM"))
                .fluentPut("prjcode", d.getString("PRJCODE"))
                .fluentPut("prjnum", prjnum)
                .fluentPut("buildplannum", d.getString("BUILDPLANNUM"))
                .fluentPut("projectplannum", d.getString("PROJECTPLANNUM"))
                .fluentPut("tendernum", d.getString("TENDERNUM"))

                .fluentPut("censornum", d.getString("CENSORNUM"))
                .fluentPut("bargaindays", d.getString("BARGAINDAYS"))
                .fluentPut("datalevel", d.getString("DATALEVEL"))
                .fluentPut("sgusername", d.getString("SGUSERNAME"))
                .fluentPut("sgcorpname", d.getString("SGCORPNAME"))

                .fluentPut("jlusername", d.getString("JLUSERNAME"))
                .fluentPut("jlcorpname", d.getString("JLCORPNAME"))
                .fluentPut("contractmoney", d.getString("CONTRACTMONEY"))
                .fluentPut("area", d.getString("AREA"))
                .fluentPut("length", d.getString("LENGTH"))
                .fluentPut("span", d.getString("SPAN"))
                .fluentPut("prjsize", d.getString("PRJSIZE"))
                .fluentPut("releasedate", getDateString(d.getLong("RELEASEDATE")))
                .fluentPut("createdate", getDateString(d.getLong("CREATEDATE")))

                .fluentPut("datasourcename", d.getString("DATASOURCENAME"))
                .fluentPut("create_time", nowTime)
                .fluentPut("update_time", nowTime)
                .fluentPut("deleted", 0);

        return JSONObject.toJSONString(j);

    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static void main(String[] args) {
        String info = "{\"xuke\":{\"AREA\":3293,\"BUILDERLICENCENUM\":\"2380021606230101-SX-001\",\"BUILDPLANNUM\":\"无\",\"CENSORNUM\":\"2380021606230101-TX-001\",\"CHECKDEPARTNAME\":\"鹤岗市建设局\",\"CHECKPERSONNAME\":\"董军\",\"CONTRACTMONEY\":145.99,\"CREATEDATE\":1472745600000,\"DATALEVEL\":\"B\",\"JLCORPID\":\"002105291321972648\",\"JLCORPNAME\":\"黑龙江省宝泉岭隆华工程监理有限责任公司\",\"JLUSERNAME\":\"靳万昌\",\"PRJNUM\":2380021606230101,\"PROJECTPLANNUM\":\"无\",\"PROVINCEBUILDERLICENCENUM\":\"2380021609020110-SX-002\",\"PROVINCEPRJNUM\":\"2380021606230110\",\"SGCORPID\":\"002105291328043009\",\"SGCORPNAME\":\"黑龙江红兴隆农垦龙泽建筑安装工程有限公司\",\"SGUSERID\":\"002303160107701765\",\"SGUSERNAME\":\"王纯良\"},\"xuke_xiangguan\":{\"list\":[{\"BUILDERLICENCENUM\":\"2380021606230101-SX-001\",\"CORPCODE\":\"91233002588127052A\",\"CORPID\":\"002105291328043009\",\"CORPNAME\":\"黑龙江红兴隆农垦龙泽建筑安装工程有限公司\",\"CORPROLE\":\"施工企业\",\"IDCARD\":\"220722**********11\",\"IDCARDTYPENUM\":\"1\",\"PERTYPE\":\"项目经理\",\"RN\":1,\"USERID\":\"002303160107701765\",\"USERNAME\":\"王纯良\"},{\"BUILDERLICENCENUM\":\"2380021606230101-SX-001\",\"CORPCODE\":\"91233000684888855E\",\"CORPID\":\"002105291241568164\",\"CORPNAME\":\"黑龙江三元建筑设计有限公司\",\"CORPROLE\":\"设计企业\",\"PERTYPE\":\"暂无\",\"RN\":2},{\"BUILDERLICENCENUM\":\"2380021606230101-SX-001\",\"CORPCODE\":\"70271650-5\",\"CORPID\":\"002105291321972648\",\"CORPNAME\":\"黑龙江省宝泉岭隆华工程监理有限责任公司\",\"CORPROLE\":\"监理企业\",\"IDCARD\":\"230403**********13\",\"IDCARDTYPENUM\":\"1\",\"PERTYPE\":\"总监理工程师\",\"RN\":3,\"USERNAME\":\"靳万昌\"},{\"BUILDERLICENCENUM\":\"2380021606230101-SX-001\",\"CORPCODE\":\"无\",\"CORPNAME\":\"无\",\"CORPROLE\":\"勘察企业\",\"PERTYPE\":\"暂无\",\"RN\":4}],\"pageNum\":0,\"pageSize\":10,\"total\":4},\"yhc_time\":\"2023-08-11\"}";
        GetConstructionPermitInfo j = new GetConstructionPermitInfo();
        System.out.println(j.evaluate(info));
    }
}
