package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.regex.Pattern;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetConstructionProjectDetailInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }
    private static final Pattern pattern_number = Pattern.compile("[^0-9.]");

    public static String cleanupNotNumber(String s) {
        if (StringUtils.isBlank(s)) return "";
        String s1 = pattern_number.matcher(s).replaceAll("");
        try {
            return new BigDecimal(s1).stripTrailingZeros().toPlainString();
        } catch (Exception e) {
            return "";
        }
    }

    public String evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;

        JSONObject d = JSONObject.parseObject(info);
        JSONObject j = new JSONObject();
        String nowTime = nowDate(YYYY_MM_DDHHMMSS);
        String prjnum = d.getString("PRJNUM");
        String rowkey = concatws("", prjnum);
        Double nationalpercenttage = d.getDouble("NATIONALPERCENTTAGE");
        if (null == nationalpercenttage || nationalpercenttage <= 0) {
            nationalpercenttage = null;
        }
        j.fluentPut("rowkey", rowkey)
                .fluentPut("prjnum", prjnum)
                .fluentPut("provinceprjnum", d.getString("PROVINCEPRJNUM"))
                .fluentPut("prjcode", d.getString("PRJCODE"))
                .fluentPut("prjtypenum", d.getString("PRJTYPENUM"))
                .fluentPut("province", d.getString("PROVINCE"))
                .fluentPut("city", d.getString("CITY"))
                .fluentPut("county", d.getString("COUNTY"))
                .fluentPut("address", d.getString("ADDRESS"))
                .fluentPut("locationx", d.getString("LOCATIONX"))
                .fluentPut("locationy", d.getString("LOCATIONY"))
                .fluentPut("prjapprovalnum", d.getString("PRJAPPROVALNUM"))
                .fluentPut("prjapprovallevelnum", d.getString("PRJAPPROVALLEVELNUM"))
                .fluentPut("prjapprovaldepart", d.getString("PRJAPPROVALDEPART"))
                .fluentPut("prjapprovaldate", getDateString(d.getLong("PRJAPPROVALDATE")))

                .fluentPut("buildcorpname", d.getString("BUILDCORPNAME"))
                .fluentPut("buildcorpcode", d.getString("BUILDCORPCODE"))
                .fluentPut("buildplannum", d.getString("BUILDPLANNUM"))
                .fluentPut("projectplannum", d.getString("PROJECTPLANNUM"))
                .fluentPut("invproperty", d.getString("INVPROPERTY"))
                .fluentPut("prjtwodimcode", d.getString("PRJTWODIMCODE"))
                .fluentPut("fundsource", d.getString("FUNDSOURCE"))

//                .fluentPut("nationalpercenttage", StringUtils.isNotBlank(d.getString("NATIONALPERCENTTAGE")) ? d.getString("NATIONALPERCENTTAGE") + "%" : null)
                .fluentPut("nationalpercenttage", nationalpercenttage != null ? cleanupNotNumber(nationalpercenttage.toString()) + "%" : null)
                .fluentPut("allinvest", d.getString("ALLINVEST"))
                .fluentPut("allarea", d.getString("ALLAREA"))
                .fluentPut("alllength", d.getString("ALLLENGTH"))
                .fluentPut("prjpropertynum", d.getString("PRJPROPERTYNUM"))
                .fluentPut("prjsize", d.getString("PRJSIZE"))
                .fluentPut("is_fake", d.getString("ISMAJOR"))
                .fluentPut("prjfunctionnum", d.getString("PRJFUNCTIONNUM"))
                .fluentPut("begindate", getDateString(d.getLong("BEGINDATE")))
                .fluentPut("enddate", getDateString(d.getLong("ENDDATE")))

                .fluentPut("jzjninfo", d.getString("JZJNINFO"))
                .fluentPut("cxxminfo", d.getString("CXXMINFO"))
                .fluentPut("datalevel", d.getString("DATALEVEL"))

                .fluentPut("create_time", nowTime)
                .fluentPut("update_time", nowTime)
                .fluentPut("deleted", 0);

        return JSONObject.toJSONString(j);

    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static void main(String[] args) {
        String info = "{\"ADDRESS\":\"江西省赣州市经济技术开发区香港工业园北区天赋路2号\",\"ALLAREA\":30,\"ALLINVEST\":45,\"BUILDCORPCODE\":\"91360703MA398PCD52\",\"BUILDCORPNAME\":\"森信能源科技有限公司\",\"CHECKDEPARTNAME\":\"萍乡市兴健建筑工程施工图审查有限公司\",\"CHECKPERSONNAME\":\"欧阳辉群\",\"CITY\":\"赣州市\",\"CITYNUM\":360700,\"COUNTYNUM\":360782,\"CREATEDATE\":1594797031000,\"DATALEVEL\":\"C\",\"DATALEVELVALUE\":\"由县级住房和城乡建设主管部门审核确认\",\"DATASOURCE\":1,\"DATASOURCENAME\":\"业务办理\",\"ID\":2669850,\"INVPROPERTY\":\"非国有投资\",\"INVPROPERTYNUM\":\"103\",\"ISMAJOR\":0,\"IS_FAKE\":0,\"LASTUPDATEDATE\":1615458674000,\"LOCATIONX\":114.880114,\"LOCATIONY\":25.871657,\"PRJAPPROVALDATE\":1615363187000,\"PRJAPPROVALDEPART\":\"/\",\"PRJFUNCTIONNUM\":\"其他\",\"PRJNAME\":\"泓森信撬装式加注装置\",\"PRJNUM\":3607822103110018,\"PRJPROPERTYNUM\":\"新建\",\"PRJSIZE\":\"拟在江西省赣州市经济技术开发区香港工业园北区天赋路2号我单位停车场内，采购安装一台阻隔防爆撬装式加注装置，设备长*宽*高；12.3*2.83*2.8，占地面积45平方米，用于企业内部车辆、机械加油服务。总投资30万元，其中建设投资1.5万元，设备及技术投资28.5万元\",\"PRJTYPENUM\":\"其他\",\"PROVINCE\":\"江西省\",\"PROVINCELASTUPDATEDATE\":1615363289000,\"PROVINCENUM\":360000,\"PROVINCEPRJNUM\":\"360782202007150301\"}";
        GetConstructionProjectDetailInfo j = new GetConstructionProjectDetailInfo();
        System.out.println(j.evaluate(info));
    }
}
