package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetParticipatingUnitsInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }


    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        return Optional.ofNullable(JSONObject.parseObject(info).getJSONArray("records"))
                .orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("prjnum")))
                .map(d -> {
                    JSONObject j = new JSONObject();
                    String nowTime = nowDate(YYYY_MM_DDHHMMSS);
                    String prjnum = d.getString("prjnum");
                    String corpname = d.getString("corpname");
                    String personname = d.getString("personname");
                    String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", corpname, personname))));
                    j.fluentPut("rowkey", rowkey)
                            .fluentPut("prjnum", prjnum)
                            .fluentPut("corprolenum", d.getInteger("corprolenum"))
                            .fluentPut("corpcode", d.getString("corpcode"))
                            .fluentPut("personname", d.getString("personname"))
                            .fluentPut("corpname", corpname)
                            .fluentPut("personphone", d.getString("personphone"))
                            .fluentPut("idcard", d.getString("idcard"))
                            .fluentPut("update_time", nowTime)
                            .fluentPut("create_time", nowTime)
                            .fluentPut("deleted", 0)
                    ;
                    return JSONObject.toJSONString(j);
                }).collect(Collectors.toList());
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"records\":[{\"corpcode\":\"400002689\",\"corpid\":\"002105291239452140\",\"corpname\":\"建设综合勘察研究设计院有限公司\",\"corprolenum\":1,\"prjnum\":\"1100000706259901\"},{\"corpid\":\"002105291239452140\",\"corpname\":\"建设综合勘察研究设计院有限公司\",\"corprolenum\":1,\"prjnum\":\"1100000706259901\"},{\"corpcode\":\"801352663\",\"corpname\":\"北京电力设计院\",\"corprolenum\":2,\"prjnum\":\"1100000706259901\"},{\"corpname\":\"北京电力设计院\",\"corprolenum\":2,\"prjnum\":\"1100000706259901\"},{\"corpname\":\"北京康城市政工程有限公司\",\"corprolenum\":3,\"prjnum\":\"1100000706259901\"},{\"corpcode\":\"101387814\",\"corpid\":\"002105291248676903\",\"corpname\":\"北京四方工程建设监理有限责任公司\",\"corprolenum\":4,\"idcardtypenum\":\"1\",\"personname\":\"谷林岗\",\"prjnum\":\"1100000706259901\"}],\"yhc_time\":\"2023-03-27\"}";
        GetParticipatingUnitsInfo j = new GetParticipatingUnitsInfo();
        System.out.println(j.evaluate(info));
    }
}
