package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;

import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.Optional;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @Author: π
 * @Date: 2020/5/14 16:26
 * @Description: 建筑维度
 */
public class GetWorkingDrawingInfo extends UDF {

    public static final DateTimeFormatter YYYY_MM_DDHHMMSS = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    public static String getDateString(Long tt) {
        if (null == tt) return null;
        Date d = new Date(tt);
        return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(d);
    }

    public static String nowDate(DateTimeFormatter pattern) {
        if (pattern == null) {
            pattern = DateTimeFormatter.ISO_DATE;
        }
        return LocalDateTime.now().format(pattern);
    }


    public List<String> evaluate(String info) {
        if (StringUtils.isBlank(info)) return null;
        return Optional.ofNullable(JSONObject.parseObject(info).getJSONArray("records"))
                .orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .filter(x -> StringUtils.isNotBlank(x.getString("prjNum")))
                .map(d -> {
                    JSONObject j = new JSONObject();
                    String nowTime = nowDate(YYYY_MM_DDHHMMSS);
                    String prjnum = d.getString("prjNum");
                    String censornum = d.getString("censorNum");
                    String rowkey = concatws("_", prjnum, md5(cleanup(concatws("", censornum))));
                    j.fluentPut("rowkey", rowkey)
                            .fluentPut("censornum", d.getString("censorNum"))
                            .fluentPut("prjnum", d.getString("prjNum"))
                            .fluentPut("provincecensornum", d.getString("provinceCensorNum"))
                            .fluentPut("censorcorpname_credit_code", d.getString("censorCorpCode"))
                            .fluentPut("censorcorpname", d.getString("censorCorpName"))
                            .fluentPut("onecensorispass", d.getString("oneCensorIsPass"))
                            .fluentPut("censoredate", d.getString("censorEDate") + " 00:00:00")
                            .fluentPut("createdate", d.getString("createDate") + " 00:00:00")
                            .fluentPut("one_review_number", d.getString("oneCensorWfqtCount"))
                            .fluentPut("onecensorwfqtcontent", d.getString("oneCensorWfqtContent"))
                            .fluentPut("is_joint_review", d.getString("isLS"))
                            .fluentPut("fire_fighting_time", d.getString("xFCensorEDate"))
                            .fluentPut("fire_fighting_number", d.getString("xFCensorNum"))
                            .fluentPut("people_fighting_time", d.getString("rFCensorEDate"))
                            .fluentPut("people_fighting_number", d.getString("rFCensorNum"))
                            .fluentPut("people_fighting_institution", d.getString("rFCensorCorpName"))
                            .fluentPut("fire_fighting_institution", d.getString("xFCensorCorpName"))
                            .fluentPut("prjsize", d.getString("prjSize"))
                            .fluentPut("datalevel", d.getString("dataLevel"))
                            .fluentPut("create_time", nowTime)
                            .fluentPut("update_time", nowTime)
                            .fluentPut("deleted", 0)
                    ;
                    return JSONObject.toJSONString(j);
                })
                .collect(Collectors.toList());
    }


    public static String concatws(String seq, String... strings) {
        return Stream.of(strings).filter(Objects::nonNull).collect(Collectors.joining(seq));
    }

    public static String md5(String s) {
        return DigestUtils.md5Hex(s);
    }


    public static void main(String[] args) {
        String info = "{\"records\":[{\"censorCorpCode\":\"79962762-0\",\"censorCorpName\":\"温州新正施工图审查咨询有限公司\",\"censorEDate\":\"2013-11-19\",\"censorNum\":\"3303001307010101-TX-001\",\"createDate\":\"2013-07-01\",\"dataLevel\":\"D\",\"oneCensorIsPass\":0,\"prjNum\":\"3303001307010101\",\"provinceCensorNum\":\"WKFD2013138\"}],\"yhc_time\":\"2023-03-24\"}";
        GetWorkingDrawingInfo j = new GetWorkingDrawingInfo();
        System.out.println(j.evaluate(info));
    }
}
