package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPath;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.util.HashSet;
import java.util.IntSummaryStatistics;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;


/**
 * @author: XuJiakai
 * 2021/6/2 10:49
 */
public class JsonArrayIdAndNameSymmetricCheck extends UDF {
    private static final Set<String> condition = new HashSet<String>() {
        {
            add("gt");
            add("gte");
            add("lt");
            add("lte");
            add("GT");
            add("GTE");
            add("LT");
            add("LTE");
        }
    };

    public Boolean evaluate(String val, String id_json_path, String name_json_path, String ignore_condition, Integer ignore_size) {
        if (!condition.contains(ignore_condition)) {
            throw new RuntimeException("请输入正确的表达式：gt,gte,lt,lte");
        }
        if (StringUtils.isEmpty(val)) {
            return true;
        }
        try {
            JSONArray jsonArray = JSON.parseArray(val);
            IntSummaryStatistics collect = jsonArray.stream().map(o -> {
                JSONObject jsonObject = ((JSONObject) o);
                String id = (String) JSONPath.eval(jsonObject, id_json_path);
                String name = (String) JSONPath.eval(jsonObject, name_json_path);

                if (StringUtils.isEmpty(name) && StringUtils.isNotBlank(id)) {
                    throw new RuntimeException("存在name为空，但id有值数据，请手动排查！");
                }
                if (StringUtils.isEmpty(name)) {
                    return null;
                }
                if (StringUtils.isNotBlank(id)) {
                    return null;
                }

                if (isContinue(name, ignore_condition, ignore_size)) {
                    return null;
                }
                return 1;
            }).filter(Objects::nonNull).collect(Collectors.summarizingInt(x -> x));
            long sum = collect.getSum();
            return sum == 0;
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private Boolean isContinue(String name, String ignore_condition, int ignore_size) {
        switch (ignore_condition.toUpperCase()) {
            case "GT":
                if (name.length() > ignore_size) {
                    return true;
                }
            case "GTE":
                if (name.length() >= ignore_size) {
                    return true;
                }
            case "LT":
                if (name.length() < ignore_size) {
                    return true;
                }
            case "LTE":
                if (name.length() <= ignore_size) {
                    return true;
                }
            default:
                return false;
        }
    }

    public static void main(String[] args) {
        JsonArrayIdAndNameSymmetricCheck
                check = new JsonArrayIdAndNameSymmetricCheck();
        Boolean lte = check.evaluate("[{\"pledgee\":\"巴东恒信担保有限公司\",\"pledgee_id\":\"\"},{\"pledgor\":\"汪建银\",\"pledgor_id\":\"\"}]"
                , "$.pledgee_id", "$.pledgee", "lte", 3);

        System.out.println(lte);
    }
}
