package com.winhc.bigdata.udf;

import cn.hutool.core.lang.Tuple;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * @Author: π
 * @Description: 当事人映射律师
 * [{"name":"余翊衔","party_title":"原告","litigant_id":""}]
 */
public class Name2Lawyer extends UDF {


    public String evaluate(String name, String lawyer) {
        if (StringUtils.isBlank(name) || "[]".equals(name)) {
            return name;
        }
        Map<String, JSONArray> m;
        if (StringUtils.isBlank(lawyer) || "[]".equals(lawyer)) {
            m = new HashMap<>();
        } else {
            m = JSON.parseArray(lawyer).toJavaList(JSONObject.class)
                    .stream()
                    .filter(j -> j.containsKey("name") && j.containsKey("lawyer_info"))
                    .map(j -> new Tuple(j.getString("name"), j.getJSONArray("lawyer_info")))
                    .collect(Collectors.toMap(j -> (String) j.get(0), t -> (JSONArray) t.get(1), (n, o) -> n));
        }

        List<JSONObject> re = JSON.parseArray(name).toJavaList(JSONObject.class)
                .stream()
                .filter(j -> j.containsKey("name"))
                .peek(j -> {
                    JSONArray l = m.getOrDefault(j.getString("name"), new JSONArray());
                    j.put("lawyer_info", l);
                }).collect(Collectors.toList());
        return JSONObject.toJSONString(re);

    }

    public static void main(String[] args) {
        Name2Lawyer res = new Name2Lawyer();
        System.out.println(res.evaluate("[{\"name\":\"333\",\"party_title\":\"原告\",\"litigant_id\":\"\"},{\"name\":\"22\",\"party_title\":\"被告\",\"litigant_id\":\"\"}]", "[{\"judge_tendency\":\"对方撤诉\",\"litigant_id\":\"e42974972b293b41bcf6fb219b51c525\",\"name\":\"111\",\"lawyer_info\":[{\"lawfirm_name\":\"福建尚坤律师事务所\",\"lawyer_name\":\"钟开航\"},{\"lawfirm_name\":\"福建尚坤律师事务所\",\"lawyer_name\":\"梁婕\"}]},{\"judge_tendency\":\"对方撤诉\",\"litigant_id\":\"e42974972b293b41bcf6fb219b51c525\",\"name\":\"22\",\"lawyer\":[{\"lawfirm_name\":\"福建尚坤律师事务所\",\"lawyer_name\":\"钟开航\"},{\"lawfirm_name\":\"福建尚坤律师事务所\",\"lawyer_name\":\"梁婕\"}]}]"));
    }
}
