package com.winhc.bigdata.udf;

import com.aliyun.odps.udf.UDF;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.math.NumberUtils;


import java.util.Arrays;
import java.util.List;
import java.util.regex.Pattern;

/**
 * @author ZhangJi
 * @since 2021-08-27 10:45
 */
public class ToIntervalSalary extends UDF {
    private static final List<Integer> MIAN_YI = Arrays.asList(null, null);
    private static final Pattern p = Pattern.compile("[^0-9-.(（]");

    public List<Integer> evaluate(String salary) {
        if (StringUtils.isEmpty(salary) || salary.contains("电话")) {
            return MIAN_YI;
        }
        salary = salary.replaceAll("[—~到]", "-");
        boolean returnSmall = false;
        boolean returnBig = false;
        if (salary.contains("以上") || salary.contains("起") || salary.contains("底薪")) {
            returnSmall = true;
        }
        if (salary.contains("以下")) {
            returnBig = true;
        }
        double factor = 1;
        if (salary.contains("万") || salary.contains("w") || salary.contains("W")) {
            factor = 10000;
        }
        if (salary.contains("k") || salary.contains("K") || salary.contains("千")) {
            factor = 1000;
        }
        if (salary.contains("年薪")) {
            factor = factor / 12;
        }
        salary = p.matcher(salary).replaceAll("");
        double f = factor;
        int[] ints = Arrays.stream(salary.split("[-wWKk万千元(（每]"))
                .filter(NumberUtils::isNumber)
                .filter(s -> s.length() < 8)
                .mapToDouble(Double::valueOf)
                .mapToInt(d -> (int) d).map(i -> (int)(i * f))
                .toArray();
        if (ints.length == 0) {
            return MIAN_YI;
        } else if (ints.length == 1) {
            if (returnSmall) {
                return Arrays.asList(ints[0], null);
            } else if (returnBig) {
                return Arrays.asList(null, ints[0]);
            }
            return Arrays.asList(ints[0], ints[0]);
        } else if (ints.length == 2) {
            return Arrays.asList(ints[0], ints[1]);
        }
        return MIAN_YI;
    }

    public static void main(String[] args) {
        System.out.println(new ToIntervalSalary().evaluate("100000年薪\n"));
    }
}
