package com.winhc.bigdata.udf.etl;

import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

/**
 * @author: XuJiakai
 * 2021/8/23 17:22
 * <p>
 * 限高提取申请人
 */
public class CompanyZxrRestrictProposer extends UDF {

    private final static Pattern pattern = Pattern.compile(".*立案执行申请人(?<name>.*?)申请执行你.*");

    private final static Set<String> set = new HashSet<String>() {
        {
            add("本院刑庭");
            add("刑事审判庭");
            add("刑庭");
            add("刑二庭");
            add("刑一庭");
            add("本院");
            add("依职权");
            add("国库");
            add("本院刑事审判庭");
            add("刑庭移送");
        }
    };

    public List<String> evaluate(String content) {
        if (StringUtils.isEmpty(content)) {
            return null;
        }
        content = content.replaceAll("[\r\n\t ]", "");
        Matcher matcher = pattern.matcher(content);
        if (matcher.matches()) {
            String name = matcher.group("name");
            List<String> collect = Arrays.asList(name.split("、"))
                    .stream()
                    .filter(StringUtils::isNotBlank)
                    .filter(s -> s.length() > 1)
                    .filter(s -> !set.contains(s))
                    .collect(Collectors.toList());
            if (collect.isEmpty()) {
                return null;
            } else {
                return collect;
            }
        }
        return null;
    }

    public static void main(String[] args) {
        String content = "青海省高级人民法院\n" +
                "限制消费令\n" +
                "（2016）青执38号\n" +
                "青海健翔新型环保建材集团有限公司\n" +
                "\t本院于2016年06月06日立案执行申请人青海四维信用担保\n" +
                "有限公司申请执行你单位追偿权纠纷一案，因你单位未按执行\n" +
                "通知书指定的期间履行生效法律文书确定的给付义务，本院依\n" +
                "照《中华人民共和国民事诉讼法》第二百五十五条和《最高人\n" +
                "民法院关于限制被执行人高消费及有关消费的若干规定》第一\n" +
                "条、第三条的规定，对你单位采取限制消费措施，限制你单位\n" +
                "及你单位（法定代表人、主要负责人、影响债务履行的直接责\n" +
                "任人员、实际控制人）南雪志不得实施以下高消费及非生活和\n" +
                "工作必需的消费行为：（一）乘坐交通工具时，选择飞机、列\n" +
                "车软卧、轮船二等以上舱位；（二）在星级以上宾馆、酒店、\n" +
                "夜总会、高尔夫球场等场所进行高消费；（三）购买不动产或\n" +
                "者新建、扩建、高档装修房屋；（四）租赁高档写字楼、宾馆\n" +
                "、公寓等场所办公；（五）购买非经营必需车辆；（六）旅游\n" +
                "、度假；（七）子女就读高收费私立学校；（八）支付高额保\n" +
                "费购买保险理财产品；（九）乘坐G字头动车组列车全部座位、\n" +
                "其他动车组列车一等以上座位等其他非生活和工作必需的消费\n" +
                "行为。如你单位（法定代表人、主要负责人、影响债务履行的\n" +
                "直接责任人员、实际控制人）因私消费以个人财产实施前述行\n" +
                "为的，可以向本院提出申请。如你单位因经营必需而进行前述\n" +
                "禁止的消费活动的，应当向本院提出申请，获批准后方可进行\n" +
                "。\n" +
                "\t如违反限制消费令，经查证属实的，本院将依照《中华人\n" +
                "民共和国民事诉讼法》第一百一十一条的规定，予以罚款、拘\n" +
                "留；情节严重，构成犯罪的，依法追究刑事责任。\n" +
                "\t此令\n" +
                "二〇一八年八月一日\n";

        CompanyZxrRestrictProposer b = new CompanyZxrRestrictProposer();
        List<String> list = b.evaluate(content);
        System.out.println(list);

    }


}
