package com.winhc.bigdata.udf.etl;

import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;

import java.text.DecimalFormat;
import java.util.regex.Pattern;

/**
 * @author: XuJiakai
 * 2022/2/15 09:20
 * 注册资本格式化
 * Ps. 800.000000万元 -> 800万元
 */
public class RegisteredCapitalFormat extends UDF {
    //private static final Pattern pattern = Pattern.compile("([^\\x00-\\x7F]+|[\\s]+)");
    private static final Pattern pattern = Pattern.compile("[^0-9\\\\.]+");
    DecimalFormat decimalFormat = new DecimalFormat("0.###########");

    public String evaluate(String content) {
        if (StringUtils.isBlank(content)) {
            return null;
        }
        try {
            String prefix = pattern.matcher(content).replaceAll("")
                    .replaceAll("\\s+", "");
            String unit = content.replace(prefix, "")
                    .replaceAll("\\s+", "");
            double v = Double.parseDouble(prefix);
            return decimalFormat.format(v) + unit;
        } catch (Exception e) {
            return content;
        }
    }

    public static void main(String[] args) {
        RegisteredCapitalFormat registeredCapitalFormat = new RegisteredCapitalFormat();
        String s = "50.00 （单位：元/万元）";
        //String s = "0.0000 万元 人民币";
        //String s = "10 万元";
        //String s = "10 万元 人民币";
        //String s = "10.00100 万元 人民币";
        //String s = "5000.000000万";
        String evaluate = registeredCapitalFormat.evaluate(s);
        System.out.println(evaluate);
    }
}


