package com.winhc.bigdata.udf;

import com.aliyun.odps.udf.UDF;

import java.util.Arrays;
import java.util.List;

import static org.apache.commons.lang.StringUtils.contains;
import static org.apache.commons.lang.StringUtils.endsWith;

/**
 * @author: π
 * 2023/3/13 16:57
 * vendinc  营业总收入
 * maibusinc  主营业务收入
 * assgro  资产总额
 * progro  利润总额
 * netinc  净利润
 * ratgro  纳税总额
 */
public class finance_info_update extends UDF {

    public List<Double> evaluate(String company_name, Double vendinc, Double maibusinc, Double assgro, Double progro
            , Double netinc, Double ratgro, Double reg_capital_amount, String company_org_type) {


        //营收/注册资本倍数
        int ve_times = 1000;
        //缩小比例
        Integer reduce_times = 10000;
        //营收大于100亿,营收是注册资本1000倍,非分公司
        if (vendinc != null && reg_capital_amount != null && vendinc > 100 * 10000
                && vendinc / (reg_capital_amount / 1000000) >= ve_times
                && !(contains(company_org_type, "分") || endsWith(company_name, "分公司"))){

            Double tmp_vendinc = vendinc / reduce_times;
            Double tmp_maibusinc = maibusinc;
            Double tmp_assgro = assgro;
            Double tmp_progro = progro;
            Double tmp_netinc = netinc;
            Double tmp_ratgro = ratgro;
            //营收必须大于主营业务
            if (maibusinc != null && tmp_vendinc < maibusinc) {
                tmp_maibusinc = maibusinc / reduce_times;
            }
            //资产总额大于营收1000倍,或者大于10亿
            if (assgro != null && (assgro / tmp_vendinc > 1000 || assgro > 10 * 10000)) {
                tmp_assgro = assgro / reduce_times;
            }
            //利润总额
            //净利润
            if (progro != null && (tmp_vendinc < progro || Math.abs(progro) / tmp_vendinc > 1000)) {
                tmp_progro = progro / reduce_times;
            }
            if (netinc != null && (tmp_vendinc < netinc || Math.abs(netinc) / tmp_vendinc > 1000)) {
                tmp_netinc = netinc / reduce_times;
            }
            //纳税总额大于营收 或者 大于10000
            if (ratgro != null && (tmp_vendinc < ratgro || ratgro > 10000)) {
                tmp_ratgro = ratgro / reduce_times;
            }
            return Arrays.asList(tmp_vendinc, tmp_maibusinc, tmp_assgro, tmp_progro, tmp_netinc, tmp_ratgro);
        } else{
            return Arrays.asList(vendinc, maibusinc, assgro, progro, netinc, ratgro);
        }
    }


    public static void main(String[] args) {
        finance_info_update j = new finance_info_update();
        String company_name = "嘉峪关市汇鹏昌隆商贸有限责任公司";
        Double vendinc = 1192934.52;
        Double maibusinc = 119.293452;
        Double assgro = 160.75;
        Double progro = 1.9;
        Double netinc = 1.81;
        Double ratgro = 1.99;
        Double reg_capital_amount = 200000000D;
        String company_org_type = "有限责任公司(自然人独资)";
        List<Double> re = j.evaluate(company_name, vendinc, maibusinc, assgro, progro, netinc, ratgro, reg_capital_amount, company_org_type);
        System.out.println(re);
    }

}
