package com.winhc.bigdata.udf.justice;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.ExecutionContext;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.udf.UDFException;
import com.winhc.bigdata.bean.case_no.CaseNoRegionInfoEntity;
import com.winhc.bigdata.utils.BaseUtils;
import com.winhc.bigdata.utils.CaseNoRegionUtils;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @Author: XuJiakai
 * 2023/11/6 9:54
 * <p>
 * function name: case_no_area_code
 */
public class CaseNoRegionInfoUDF extends UDF {

    private List<String> caseNoKeyword = null;
    Map<String, CaseNoRegionInfoEntity> case_no_keyword_map = null;
    Map<String, CaseNoRegionInfoEntity> court_name_map = null;


    @Override
    public void setup(ExecutionContext ctx) throws UDFException, IOException {
        Map<String, CaseNoRegionInfoEntity> caseNoRegionInfo = CaseNoRegionUtils.getCaseNoRegionInfo();
        caseNoKeyword = caseNoRegionInfo.keySet().stream().filter(Objects::nonNull).sorted(Comparator.comparingInt(String::length).reversed()).collect(Collectors.toList());
        case_no_keyword_map = caseNoRegionInfo;


        Map<String, CaseNoRegionInfoEntity> collect = caseNoRegionInfo.values().stream().collect(Collectors.toMap(CaseNoRegionInfoEntity::getCourt_name, e -> e, (e1, e2) -> {
            return e1;
        }));
        court_name_map = collect;
    }

    public String evaluate(String case_no, String court_name) {
        JSONObject jsonObject = new JSONObject();
        CaseNoRegionInfoEntity caseNoRegionInfoEntity = null;
        if (StringUtils.isNotEmpty(court_name) && court_name_map.containsKey(court_name)) {
            caseNoRegionInfoEntity = court_name_map.get(court_name);
        }

        String caseNoKeyword = getCaseNoKeyword(case_no);
        if (caseNoRegionInfoEntity == null && caseNoKeyword != null && case_no_keyword_map.containsKey(caseNoKeyword)) {
            caseNoRegionInfoEntity = case_no_keyword_map.get(caseNoKeyword);
        }
        if (caseNoRegionInfoEntity == null) {
            return null;
        }

        jsonObject.put("province_code", caseNoRegionInfoEntity.getProvince_code());
        jsonObject.put("city_code", caseNoRegionInfoEntity.getCity_code());
        jsonObject.put("district_code", caseNoRegionInfoEntity.getDistrict_code());
        jsonObject.put("province", caseNoRegionInfoEntity.getProvince());
        jsonObject.put("city", caseNoRegionInfoEntity.getCity());
        jsonObject.put("district", caseNoRegionInfoEntity.getDistrict());
        jsonObject.put("court_level", caseNoRegionInfoEntity.getCourt_level());
        jsonObject.put("court_code", caseNoRegionInfoEntity.getCourt_code());
        jsonObject.put("superior_court_code", caseNoRegionInfoEntity.getSuperior_court_code());


        return BaseUtils.toString(jsonObject);
    }

    private String getCaseNoKeyword(String case_no) {
        if (StringUtils.isEmpty(case_no)) {
            return null;
        }
        for (String s : caseNoKeyword) {
            if (case_no.contains(s)) {
                return s;
            }
        }
        return null;
    }

    public static void main(String[] args) throws UDFException, IOException {
        CaseNoRegionInfoUDF caseNoRegionInfoUDF = new CaseNoRegionInfoUDF();
        caseNoRegionInfoUDF.setup(null);
        System.out.println(caseNoRegionInfoUDF.evaluate("XXX沪XXX", ""));

    }

}
