package com.winhc.bigdata.utils;

import java.math.BigDecimal;

/**
 * @Author: XuJiakai
 * @Date: 2020/9/2 17:57
 * @Description:
 */
public class BigDecimalUtil {
    // 进行加法运算
    public static double add(String v1, String v2) {

        BigDecimal b1 = new BigDecimal(v1);
        BigDecimal b2 = new BigDecimal(v2);
        return b1.add(b2).doubleValue();
    }

    public static double add(double v1, double v2) {
        BigDecimal b1 = new BigDecimal(v1);
        BigDecimal b2 = new BigDecimal(v2);
        return b1.add(b2).doubleValue();
    }

    // 进行减法运算
    public static double subtract(String v1, String v2) {
        BigDecimal b1 = new BigDecimal(v1);
        BigDecimal b2 = new BigDecimal(v2);
        return b1.subtract(b2).doubleValue();
    }

    public static double subtract(double v1, double v2) {
        BigDecimal b1 = new BigDecimal(v1);
        BigDecimal b2 = new BigDecimal(v2);
        return b1.subtract(b2).doubleValue();
    }

    // 进行乘法运算
    public static double mul(String d1, String d2) {
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        return b1.multiply(b2).doubleValue();
    }

    public static double mul(double d1, double d2) {
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        return b1.multiply(b2).doubleValue();
    }

    // 进行除法运算
    public static double div(String d1, String d2, int len) {
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        if (b2.doubleValue() == 0) {
            return 0;
        }
        return b1.divide(b2, len, BigDecimal.ROUND_HALF_UP).doubleValue();
    }

    public static double div(double d1, double d2, int len) {
        if (d2 == 0) {
            return 0;
        }
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        return b1.divide(b2, len, BigDecimal.ROUND_HALF_UP).doubleValue();
    }

    public static double div(long d1, long d2, int len) {
        if (d2 == 0) {
            return 0;
        }
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        return b1.divide(b2, len, BigDecimal.ROUND_HALF_UP).doubleValue();
    }

    // 进行四舍五入操作-len 小数点后保留几位
    public static double round(double d, int len) {
        BigDecimal b1 = new BigDecimal(d);
        BigDecimal b2 = new BigDecimal(1);
        // 任何一个数字除以1都是原数字
        // ROUND_HALF_UP是BigDecimal的一个常量，表示进行四舍五入的操作
        return b1.divide(b2, len, BigDecimal.ROUND_HALF_UP).doubleValue();
    }


    /**
     * 进行四舍五入操作 -并保留指定位数
     *
     * @param @param  d1		处理数据
     * @param @param  d2		如果为1 则自己保留多少位，100为除以100之后的结果再保留位数
     * @param @param  len  小数点保留位数
     * @param @return 参数
     * @return String    返回类型
     * @throws
     * @Title: round
     * @Description:
     */
    public static double round(String d1, String d2, int len) {
        BigDecimal b1 = new BigDecimal(d1);
        BigDecimal b2 = new BigDecimal(d2);
        // 任何一个数字除以1都是原数字
        // ROUND_HALF_UP是BigDecimal的一个常量，表示进行四舍五入的操作
        double res = b1.divide(b2, len, BigDecimal.ROUND_HALF_UP).doubleValue();
        return res;
    }

    public static Long double2Long(Double d) {
        return Math.round(d);
    }
}
