package com.winhc.bigdata.utils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.winhc.bigdata.bean.Entity;
import com.winhc.bigdata.bean.case_no.CaseNoTitleEntity;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @Author: XuJiakai
 * 2023/10/25 10:27
 */
public class CaseNoPropertiesUtils {


    public static JSONArray getCaseInfo() {
        String s = BaseUtils.readeResourceFile("case_info.json");
        JSONArray objects = JSON.parseArray(s);
        return objects;
    }


    public static Entity<List<String>, Map<String, Set<CaseNoTitleEntity>>> getCaseNoKeyword() {
        JSONArray caseInfo = getCaseInfo();
        Map<String, Set<CaseNoTitleEntity>> caseNoMap = new HashMap<>();
        Set<String> caseNoSet = new HashSet<>();
        for (Object o : caseInfo) {
            JSONObject item = ((JSONObject) o);
            recursion(item, null, caseNoMap, caseNoSet);
        }
        List<String> collect = caseNoSet.stream().filter(Objects::nonNull).sorted(Comparator.comparingInt(String::length).reversed()).collect(Collectors.toList());
        return Entity.of(collect, caseNoMap);
    }


    private static void recursion(JSONObject item, CaseNoTitleEntity partyTitle, Map<String, Set<CaseNoTitleEntity>> caseNoMap, Set<String> caseNoSet) {
        CaseNoTitleEntity thisPartyTitle = partyTitle;
        if (item.containsKey("party_title")) {
            thisPartyTitle = item.getObject("party_title", CaseNoTitleEntity.class);
        }
        if (item.containsKey("case_no_keyword")) {
            String caseNoKeyword = item.getString("case_no_keyword");
            caseNoSet.add(caseNoKeyword);
        }
        if (item.containsKey("sub_case_type")&&!item.getJSONArray("sub_case_type").isEmpty()) {
            JSONArray sub_case_type = item.getJSONArray("sub_case_type");
            for (Object o : sub_case_type) {
                recursion(((JSONObject) o), thisPartyTitle, caseNoMap, caseNoSet);
            }
        } else {
            if (item.containsKey("case_no_keyword")) {
                String caseNoKeyword = item.getString("case_no_keyword");
                if (thisPartyTitle != null) {
                    if (caseNoMap.containsKey(caseNoKeyword)) {
                        Set<CaseNoTitleEntity> caseNoTitleEntities = caseNoMap.get(caseNoKeyword);
                        caseNoTitleEntities.add(thisPartyTitle);

                    } else {
                        HashSet<CaseNoTitleEntity> set = new HashSet<>();
                        set.add(thisPartyTitle);

                        caseNoMap.put(caseNoKeyword, set);
                    }
                }
            }
        }

    }


    public static void main(String[] args) {
        Entity<List<String>, Map<String, Set<CaseNoTitleEntity>>> caseNoKeyword = getCaseNoKeyword();
        String s = BaseUtils.toString(caseNoKeyword);
        System.out.println(s);

        /*String s = "{ \"all\": [ [ \"原公诉机关\", \"原审被告人\", \"原审被告单位\" ] ], \"core\": [ \"原公诉机关\", \"原审被告人\" ] }";
        JSONObject jsonObject = JSON.parseObject(s);
        CaseNoTitleEntity caseNoTitleEntity = jsonObject.toJavaObject(CaseNoTitleEntity.class);
        System.out.println(caseNoTitleEntity);*/

    }
}
