package com.winhc.bigdata.utils;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.utils.StringUtils;
import com.github.houbb.opencc4j.util.ZhConverterUtil;
import com.winhc.bigdata.udf.etl.CompanyPhoneOrEmailMerge;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

import static com.github.stuxuhai.jpinyin.ChineseHelper.convertToSimplifiedChinese;

/**
 * @author: XuJiakai
 * 2021/12/6 11:27
 */
public class CompanyUtils {
    public static List<String> spiltNames(String val) {
        if (StringUtils.isEmpty(val)) {
            return Collections.emptyList();
        }
        return Arrays.stream(val.split("\t;\t")).map(String::trim).filter(StringUtils::isNotBlank).map(CompanyUtils::valTrim).collect(Collectors.toList());
    }

    public static String cleanup2(String s) {
        Pattern pattern = Pattern.compile("[\\u4e00-\\u9fa5]");
        if (StringUtils.isBlank(s)) return "";
        return pattern.matcher(s).replaceAll("");
    }

    public static List<String> spiltNamesPlus(String val) {
        return spiltNames(val).stream().map(CompanyUtils::cleanup2)
                .filter(StringUtils::isNotBlank).collect(Collectors.toList());
    }


    private static String valTrim(String val) {
        if (StringUtils.isBlank(val)) {
            return null;
        }
        if (val.endsWith("\t;")) {
            return val.replaceAll("\t;", "");
        } else {
            return val;
        }
    }
    private static final Pattern pattern = Pattern.compile("[^\\u4e00-\\u9fa50-9a-zA-Z]");

    public static String cleanup(String s) {
        if (StringUtils.isBlank(s)) return "";
        return pattern.matcher(s).replaceAll("");
    }

    public static Double companyScoreWeight(String reg_status, String cname, String reg_capital_amount, String company_type) {
        if (cname == null || cleanup(cname).replaceAll("[0-9]", "").length() == 1)
            return 0.01D;
        if (cleanup(cname).replaceAll("[0-9]", "").length() <= 3)
            return 0.3D;
        if (reg_status == null || reg_status.contains("销") || reg_status.contains("消"))
            return 1D;
        Double amount = reg_capital_amount == null ? 0L : Double.parseDouble(reg_capital_amount);

        Double w = Math.log(amount / 10000000 + 1) + 1;
        if ("1".equals(company_type))
            w = w + 3;
        return w;
    }

    public static JSONObject getCompanyName(String name) {
        if (StringUtils.isEmpty(name)) return null;
        else {
            String show = name.replaceAll("\t;", "").trim();
            String value = cleanup(name);
            String simplifiedChineseValue = ZhConverterUtil.toSimple(value);
            String simplifiedChinese = ZhConverterUtil.toSimple(show);
            JSONObject j = new JSONObject();
            if (show.equals(simplifiedChinese)) {
                j.put("show", show);
                j.put("value", value);
            } else {
                j.put("show", show);
                j.put("value", simplifiedChineseValue);
                j.put("simplified_chinese", simplifiedChinese);
            }
            return j;
        }
    }
}
